@@ -5,16 +5,15 @@ use strict;
 
 use Benchmark;
 
-use File::Temp;
+use POSIX qw(tmpnam);
 use File::Path qw(mkpath rmtree);
 use File::Spec;
 use IO::File;
-use Scalar::Util;
 
 use Module::Pluggable ( search_path => 'Template::Benchmark::Engines',
                         sub_name    => 'engine_plugins' );
 
-our $VERSION = '1.09_01';
+our $VERSION = '1.01';
 
 my @valid_features = qw/
     literal_text
@@ -90,18 +89,14 @@ my %option_defaults = (
     instance_reuse              => 1,
 
     #  Other options.
-    template_repeats    => 30,
-    duration            => 10,
-    dataset             => 'original',
-    style               => 'none',
-    keep_tmp_dirs       => 0,
-    skip_output_compare => 0,
+    template_repeats => 30,
+    duration         => 10,
+    style            => 'none',
+    keep_tmp_dirs    => 0,
 
     #  Plugin control.
     only_plugin      => {},
     skip_plugin      => {},
-    features_from    => {},
-    cache_types_from => {},
     );
 
 #  Which engines to try first as the 'reference output' for templates.
@@ -115,52 +110,47 @@ my %option_defaults = (
 #  choice once this module has stabilized.
 my $reference_preference = 'TS';
 
-my %datasets = (
-    original => {
-        hash1 => {
-            scalar_variable => 'I is a scalar, yarr!',
-            hash_variable   => {
-                'hash_value_key' =>
-                    'I spy with my little eye, something beginning with H.',
-                },
-            array_variable   => [ qw/I have an imagination honest/ ],
-            this => { is => { a => { very => { deep => { hash => {
-                #  No longer "it's", to avoid HTML-escaping inconsistencies
-                structure => "My god, it be full of hashes.",
-                } } } } } },
-            template_if_true  => 'True dat',
-            template_if_false => 'Nay, Mister Wilks',
-            },
-        hash2 => {
-            array_loop => [ qw/five four three two one coming ready or not/ ],
-            hash_loop  => {
-                aaa => 'first',
-                bbb => 'second',
-                ccc => 'third',
-                ddd => 'fourth',
-                eee => 'fifth',
-                },
-            records_loop => [
-                { name => 'Joe Bloggs',      age => 16,  },
-                { name => 'Fred Bloggs',     age => 23,  },
-                { name => 'Nigel Bloggs',    age => 43,  },
-                { name => 'Tarquin Bloggs',  age => 143, },
-                { name => 'Geoffrey Bloggs', age => 13,  },
-                ],
-            variable_if      => 1,
-            variable_if_else => 0,
-            variable_expression_a => 20,
-            variable_expression_b => 10,
-            variable_function_arg => 'Hi there',
-            },
+my $var_hash1 = {
+    scalar_variable => 'I is a scalar, yarr!',
+    hash_variable   => {
+        'hash_value_key' =>
+            'I spy with my little eye, something beginning with H.',
         },
-    );
+    array_variable   => [ qw/I have an imagination honest/ ],
+    this => { is => { a => { very => { deep => { hash => {
+        #  No longer "it's", to avoid HTML-escaping trap with some engines.
+        structure => "My god, it be full of hashes.",
+        } } } } } },
+    template_if_true  => 'True dat',
+    template_if_false => 'Nay, Mister Wilks',
+    };
+my $var_hash2 = {
+    array_loop => [ qw/five four three two one coming ready or not/ ],
+    hash_loop  => {
+        aaa => 'first',
+        bbb => 'second',
+        ccc => 'third',
+        ddd => 'fourth',
+        eee => 'fifth',
+        },
+    records_loop => [
+        { name => 'Joe Bloggs',      age => 16,  },
+        { name => 'Fred Bloggs',     age => 23,  },
+        { name => 'Nigel Bloggs',    age => 43,  },
+        { name => 'Tarquin Bloggs',  age => 143, },
+        { name => 'Geoffrey Bloggs', age => 13,  },
+        ],
+    variable_if      => 1,
+    variable_if_else => 0,
+    variable_expression_a => 20,
+    variable_expression_b => 10,
+    variable_function_arg => 'Hi there',
+    };
 
 sub new
 {
     my $this = shift;
-    my ( $self, $class, $options, $var_hash1, $var_hash2, %temp_options,
-        %keep_cache_types );
+    my ( $self, $class, $options );
 
     $self = {};
     $class = ref( $this ) || $this;
@@ -170,8 +160,7 @@ sub new
     $options = $self->{ options };
     while( my $opt = shift )
     {
-        if( $opt eq 'only_plugin'   or $opt eq 'skip_plugin' or
-            $opt eq 'features_from' or $opt eq 'cache_types_from' )
+        if( $opt eq 'only_plugin' or $opt eq 'skip_plugin' )
         {
             my $val = shift();
             $options->{ $opt } ||= {};
@@ -191,9 +180,6 @@ sub new
         }
         else
         {
-            #  TODO: should be croak
-            die "Unknown constructor option '$opt'"
-                unless exists $option_defaults{ $opt };
             $self->{ options }->{ $opt } = shift();
         }
     }
@@ -208,70 +194,9 @@ sub new
     delete $options->{ skip_plugin }
         unless scalar( keys( %{$options->{ skip_plugin }} ) );
     delete $options->{ features_from }
-        unless scalar( keys( %{$options->{ features_from }} ) );
+        unless $options->{ features_from };
     delete $options->{ cache_types_from }
-        unless scalar( keys( %{$options->{ cache_types_from }} ) );
-
-    if( ref( $options->{ dataset } ) )
-    {
-        #  TODO: should be croaks really.
-        die "Option 'dataset' must be a dataset name or a hashref, got: " .
-            ref( $options->{ dataset } )
-            unless ref( $options->{ dataset } ) eq 'HASH';
-        die "Option 'dataset' hashref is missing required 'hash1' key"
-            unless defined( $options->{ dataset }->{ hash1 } );
-        die "Option 'dataset' hashref is missing required 'hash2' key"
-            unless defined( $options->{ dataset }->{ hash2 } );
-        $var_hash1 = $options->{ dataset }->{ hash1 };
-        $var_hash2 = $options->{ dataset }->{ hash2 };
-    }
-    else
-    {
-        #  TODO: should be croaks really.
-        die "Unknown dataset name '$options->{ dataset }'"
-            unless defined( $datasets{ $options->{ dataset } } );
-        $var_hash1 = $datasets{ $options->{ dataset } }->{ hash1 };
-        $var_hash2 = $datasets{ $options->{ dataset } }->{ hash2 };
-    }
-
-    if( $options->{ features_from } )
-    {
-        $self->{ features } = [ @valid_features ];
-        foreach my $plugin ( $self->engine_plugins() )
-        {
-            my $leaf = _engine_leaf( $plugin );
-
-            next unless $options->{ features_from }->{ $leaf };
-
-            eval "use $plugin";
-            next if $@;
-
-            $self->{ features } = [ grep
-                {
-                    defined( $plugin->feature_syntax( $_ ) )
-                } @{$self->{ features }} ];
-        }
-    }
-    else
-    {
-        $self->{ features } =
-            [ 
-            grep { $options->{ $_ } } @valid_features
-            ];
-    }
-    #  TODO: sanity-check some features are left.
-
-    if( $options->{ cache_types_from } )
-    {
-        $self->{ cache_types } = [ @valid_cache_types ];
-        %keep_cache_types = ();
-    }
-    else
-    {
-        $self->{ cache_types } =
-            [ grep { $options->{ $_ } } @valid_cache_types ];
-    }
-    #  TODO: sanity-check some cache_types are left.
+        unless $options->{ cache_types_from };
 
     $self->{ engines } = [];
     $self->{ engine_errors } = {};
@@ -281,10 +206,8 @@ sub new
 
         #  Force-require any features_from or cache_types_from plugin,
         #  regardless of their only_plugin or skip_plugin settings.
-        if( ( not $options->{ features_from } or
-              not $options->{ features_from }->{ $leaf } ) and
-            ( not $options->{ cache_types_from } or
-              not $options->{ cache_types_from }->{ $leaf } ) )
+        if( ( ( $options->{ features_from }    || '' ) ne $leaf ) and
+            ( ( $options->{ cache_types_from } || '' ) ne $leaf ) )
         {
             if( $options->{ only_plugin } )
             {
@@ -298,54 +221,41 @@ sub new
         eval "use $plugin";
         if( $@ )
         {
-            $self->engine_error( $leaf, "Engine plugin load failure: $@" );
+            $self->engine_error( $leaf, "Engine module load failure: $@" );
         }
         else
         {
-            push @{$self->{ engines }}, $plugin;
+            if( ( $options->{ features_from } || '' ) eq $leaf )
+            {
+                unshift @{$self->{ engines }}, $plugin;
+            }
+            else
+            {
+                push @{$self->{ engines }}, $plugin;
+            }
         }
     }
 
-    %temp_options = (
-        TMPDIR   => 1,
-        );
-    $temp_options{ CLEANUP } = 0 if $self->{ options }->{ keep_tmp_dirs };
-
-    $self->{ file_temp } =
-        File::Temp->newdir( 'benchmark_XXXX', %temp_options )
-        or die "Unable to create File::Temp";
-
-    $self->{ template_dir } = File::Spec->catfile(
-        $self->{ file_temp }->dirname(),
-        'templates',
-        );
-    $self->{ cache_dir }    = File::Spec->catfile(
-        $self->{ file_temp }->dirname(),
-        'caches',
-        );
+    $self->{ template_dir } = tmpnam();
+    $self->{ cache_dir }    = $self->{ template_dir } . '.cache';
     #  TODO: failure check.
-    mkpath( $self->{ template_dir } )
-        or die "Unable to make template dir '$self->{ template_dir }': $!";
-    mkpath( $self->{ cache_dir } )
-        or die "Unable to make cache dir '$self->{ cache_dir }': $!";
+    mkpath( $self->{ template_dir } );
+    mkpath( $self->{ cache_dir } );
 
-    $self->{ feature_repeats } =
-        {
-        map
-        {
-            $_ =>
-                (
-                #  Retain positive integer values.
-                ( Scalar::Util::looks_like_number( $options->{ $_ } ) &&
-                  ( int( $options->{ $_ } ) == $options->{ $_ } ) &&
-                  ( $options->{ $_ } > 0 ) ) ?
-                $options->{ $_ } :
-                #  Normalize the rest to 1 or 0 based on true/false.
-                #  TODO: probably should warn.
-                ( $options->{ $_ } ? 1 : 0 )
-                )
-        } @{$self->{ features }}
-        };
+    if( $options->{ cache_types_from } )
+    {
+        $self->{ cache_types } = [ @valid_cache_types ];
+    }
+    else
+    {
+        $self->{ cache_types } =
+            [ grep { $options->{ $_ } } @valid_cache_types ];
+    }
+    #  TODO: sanity-check some are left.
+
+    $self->{ features } =
+        [ grep { $options->{ $_ } } @valid_features ];
+    #  TODO: sanity-check some are left.
 
     $self->{ templates }           = {};
     $self->{ benchmark_functions } = {};
@@ -389,14 +299,14 @@ sub new
             }
 
             next unless $functions and scalar( keys( %{$functions} ) );
+
             $benchmark_functions{ $cache_type } = $functions;
         }
 
-        %keep_cache_types = map { $_ => 1 }
-            keys( %keep_cache_types ),
+        $self->{ cache_types } = [
             grep { $benchmark_functions{ $_ } } @valid_cache_types
-            if $options->{ cache_types_from } and
-               $options->{ cache_types_from }->{ $leaf };
+            ]
+            if ( ( $options->{ cache_types_from } || '' ) eq $leaf );
 
         unless( %benchmark_functions )
         {
@@ -404,6 +314,9 @@ sub new
             next ENGINE;
         }
 
+        $self->{ features } = [ @valid_features ]
+            if ( ( $options->{ features_from } || '' ) eq $leaf );
+
 #print "Looking at $leaf.\n";
 #use Data::Dumper;
 #print "  features: " . Data::Dumper::Dumper( $self->{ features } ) . "\n";
@@ -417,8 +330,7 @@ sub new
             $feature_syntax = $engine->feature_syntax( $feature );
             if( defined( $feature_syntax ) )
             {
-                $template .= ( $feature_syntax . "\n" ) x
-                    ( $self->{ feature_repeats }->{ $feature } || 1 );
+                $template .= $feature_syntax . "\n";
             }
             else
             {
@@ -426,6 +338,15 @@ sub new
             }
         }
 
+        if( ( ( $options->{ features_from } || '' ) eq $leaf ) and
+            $missing_syntaxes )
+        {
+            my %missing = map { $_ => 1 } split( /\s+/, $missing_syntaxes );
+            $self->{ features } =
+                [ grep { !$missing{ $_ } } @{$self->{ features }} ];
+            $missing_syntaxes = '';
+        }
+
         if( $missing_syntaxes )
         {
             $self->engine_error( $leaf,
@@ -434,10 +355,6 @@ sub new
         }
 
         $template = $template x $options->{ template_repeats };
-        #  Allow the plugin a chance to rewrite the repeated sections,
-        #  ie: some engines require unique loop names/labels.
-        $template = $engine->preprocess_template( $template )
-            if $engine->can( 'preprocess_template' );
 
         $template_filename =
             File::Spec->catfile( $template_dir, $leaf . '.txt' );
@@ -491,11 +408,13 @@ sub new
 
     if( $options->{ cache_types_from } )
     {
+        my %needed_types = map { $_ => 1 } @{$self->{ cache_types }};
+
         #  We need to delete any benchmark functions that crept in
         #  before we figured out what cache types we needed.
         $self->{ benchmark_functions } = {
             map { $_ => $self->{ benchmark_functions }->{ $_ } }
-            grep { $keep_cache_types{ $_ } }
+            grep { $needed_types{ $_ } }
             keys( %{$self->{ benchmark_functions }} )
             };
     }
@@ -562,10 +481,6 @@ sub benchmark
                 delete $self->{ benchmark_functions }->{ $type }->{ $tag };
                 next;
             }
-            $output = ${$output} if $output and ref( $output );
-            #  [rt #59247] Normalize newline endings, some template engines
-            #  produce UNIX and some Windows line-endings when on Windows.
-            $output =~ s/\r//g if $output;
             push @outputs, [ $type, $tag, $output ];
             $reference = $#outputs if $tag eq $reference_preference;
         }
@@ -607,25 +522,21 @@ sub benchmark
         failures => [],
         };
     $result->{ errors } = $errors if %{$errors};
-
-    unless( $self->{ options }->{ skip_output_compare } )
+    foreach my $output ( @outputs )
     {
-        foreach my $output ( @outputs )
-        {
-            push @{$result->{ failures }},
-                {
-                    type   => $output->[ 0 ],
-                    tag    => $output->[ 1 ],
-                    output => defined( $output->[ 2 ] ) ?
-                              $output->[ 2 ] : "[no content returned]\n",
-                }
-                if !defined( $output->[ 2 ] ) or
-                   $output->[ 2 ] ne $result->{ reference }->{ output };
-        }
-
-        return( $result ) unless $#{$result->{ failures }} == -1;
+        push @{$result->{ failures }},
+            {
+                type   => $output->[ 0 ],
+                tag    => $output->[ 1 ],
+                output => defined( $output->[ 2 ] ) ?
+                          $output->[ 2 ] : "[no content returned]\n",
+            }
+            if !defined( $output->[ 2 ] ) or
+               $output->[ 2 ] ne $result->{ reference }->{ output };
     }
 
+    return( $result ) unless $#{$result->{ failures }} == -1;
+
     #  OK, all template output matched, time to do the benchmarks.
 
     delete $result->{ failures };
@@ -672,9 +583,8 @@ sub DESTROY
     }
     else
     {
-        #  Try to make our benchmark closures go out of scope so they
-        #  release any locks before we try to delete the temp dirs...
-        delete $self->{ benchmark_functions };
+        rmtree( $self->{ cache_dir } )    if $self->{ cache_dir };
+        rmtree( $self->{ template_dir } ) if $self->{ template_dir };
     }
 }
 
@@ -763,7 +673,7 @@ Template::Benchmark - Pluggable benchmarker to cross-compare template systems.
 
     my $bench = Template::Benchmark->new(
         duration            => 5,
-        template_repeats    => 1,
+        repeats             => 1,
         array_loop          => 1,
         shared_memory_cache => 0,
         );
@@ -796,11 +706,6 @@ UI onto L<Template::Benchmark> and gives you human-readable reports
 as a reply rather than a raw hashref, it also supports JSON output if
 you want to dump the report somewhere in a machine-readable format.
 
-If you have no template engines already installed, or you want to benchmark
-everything supported, I suggest you also look at the
-L<Task::Template::Benchmark> distribution which installs all
-the optional requirements for L<Template::Benchmark>.
-
 =head1 IMPORTANT CONCEPTS AND TERMINOLOGY
 
 =head2 Template Engines
@@ -952,69 +857,58 @@ Each of these options determines which I<cache types> are enabled
 At least one of them must be set to a true value for any benchmarks
 to be run.
 
-=item B<literal_text> => I<0> | I<1> | I<$n> (default 1)
+=item B<literal_text> => I<0> | I<1> (default 1)
 
-=item B<scalar_variable> => I<0> | I<1> | I<$n> (default 1)
+=item B<scalar_variable> => I<0> | I<1> (default 1)
 
-=item B<hash_variable_value> => I<0> | I<1> | I<$n> (default 0)
+=item B<hash_variable_value> => I<0> | I<1> (default 0)
 
-=item B<array_variable_value> => I<0> | I<1> | I<$n> (default 0)
+=item B<array_variable_value> => I<0> | I<1> (default 0)
 
-=item B<deep_data_structure_value> => I<0> | I<1> | I<$n> (default 0)
+=item B<deep_data_structure_value> => I<0> | I<1> (default 0)
 
-=item B<array_loop_value> => I<0> | I<1> | I<$n> (default 0)
+=item B<array_loop_value> => I<0> | I<1> (default 0)
 
-=item B<hash_loop_value> => I<0> | I<1> | I<$n> (default 0)
+=item B<hash_loop_value> => I<0> | I<1> (default 0)
 
-=item B<records_loop_value> => I<0> | I<1> | I<$n> (default 1)
+=item B<records_loop_value> => I<0> | I<1> (default 1)
 
-=item B<array_loop_template> => I<0> | I<1> | I<$n> (default 0)
+=item B<array_loop_template> => I<0> | I<1> (default 0)
 
-=item B<hash_loop_template> => I<0> | I<1> | I<$n> (default 0)
+=item B<hash_loop_template> => I<0> | I<1> (default 0)
 
-=item B<records_loop_template> => I<0> | I<1> | I<$n> (default 1)
+=item B<records_loop_template> => I<0> | I<1> (default 1)
 
-=item B<constant_if_literal> => I<0> | I<1> | I<$n> (default 0)
+=item B<constant_if_literal> => I<0> | I<1> (default 0)
 
-=item B<variable_if_literal> => I<0> | I<1> | I<$n> (default 1)
+=item B<variable_if_literal> => I<0> | I<1> (default 1)
 
-=item B<constant_if_else_literal> => I<0> | I<1> | I<$n> (default 0)
+=item B<constant_if_else_literal> => I<0> | I<1> (default 0)
 
-=item B<variable_if_else_literal> => I<0> | I<1> | I<$n> (default 1)
+=item B<variable_if_else_literal> => I<0> | I<1> (default 1)
 
-=item B<constant_if_template> => I<0> | I<1> | I<$n> (default 0)
+=item B<constant_if_template> => I<0> | I<1> (default 0)
 
-=item B<variable_if_template> => I<0> | I<1> | I<$n> (default 1)
+=item B<variable_if_template> => I<0> | I<1> (default 1)
 
-=item B<constant_if_else_template> => I<0> | I<1> | I<$n> (default 0)
+=item B<constant_if_else_template> => I<0> | I<1> (default 0)
 
-=item B<variable_if_else_template> => I<0> | I<1> | I<$n> (default 1)
+=item B<variable_if_else_template> => I<0> | I<1> (default 1)
 
-=item B<constant_expression> => I<0> | I<1> | I<$n> (default 0)
+=item B<constant_expression> => I<0> | I<1> (default 0)
 
-=item B<variable_expression> => I<0> | I<1> | I<$n> (default 0)
+=item B<variable_expression> => I<0> | I<1> (default 0)
 
-=item B<complex_variable_expression> => I<0> | I<1> | I<$n> (default 0)
+=item B<complex_variable_expression> => I<0> | I<1> (default 0)
 
-=item B<constant_function> => I<0> | I<1> | I<$n> (default 0)
+=item B<constant_function> => I<0> | I<1> (default 0)
 
-=item B<variable_function> => I<0> | I<1> | I<$n> (default 0)
+=item B<variable_function> => I<0> | I<1> (default 0)
 
 Each of these options sets the corresponding I<template feature> on
 or off.  At least one of these must be true for any benchmarks to
 run.
 
-If any option is set to a positive integer greater than 1, it will
-be used as a repeats value for that specific feature, indicating
-that the feature should appear in the benchmark template that
-number of times.
-
-This stacks with any C<template_repeats> constructor option, for example
-if you supply C<< scalar_variable => 2 >> and C<< template_repeats => 30 >>,
-you will have 60 C<scalar_variable> sections in the benchmark template.
-
-Support for per-feature repeats values was added in 1.04.
-
 =item B<features_from> => I<$plugin> (default none)
 
 If set, then the list of I<template features> will be drawn
@@ -1025,40 +919,6 @@ as options will be ignored and overwritten, and the plugin
 named will also be benchmarked even if you attempted to
 exclude it with the C<skip_plugin> or C<only_plugin> options.
 
-You can supply multiple plugins to C<features_from>, either
-by passing several C<features_from> attributes, or by passing
-an arrayref of plugin names, or a hashref of plugin names with
-true/false values to toggle them on or off.
-The set of features chosen will then be the largest common subset of
-features supported by those engines.
-
-  #  This sets the features to benchmark to all those supported by
-  #  Template::Benchmark::Engines::TemplateSandbox
-  $bench = Template::Benchmark->new(
-        features_from => 'TemplateSandbox',
-        );
-
-  #  This sets the features to benchmark to all those supported by BOTH
-  #  Template::Benchmark::Engines::MojoTemplate and
-  #  Template::Benchmark::Engines::HTMLTemplateCompiled
-  $bench = Template::Benchmark->new(
-        features_from => 'MojoTemplate',
-        features_from => 'HTMLTemplateCompiled',
-        );
-
-  #  This sets the features to benchmark to all those supported by BOTH
-  #  Template::Benchmark::Engines::MojoTemplate and
-  #  Template::Benchmark::Engines::HTMLTemplateCompiled
-  $bench = Template::Benchmark->new(
-        features_from => {
-            MojoTemplate         => 1,
-            HTMLTemplateCompiled => 1,
-            TemplateSandbox      => 0,
-            },
-        );
-
-Support for multiple C<features_from> values was added in 1.09.
-
 =item B<cache_types_from> => I<$plugin> (default none)
 
 If set, then the list of I<cache types> will be drawn
@@ -1069,40 +929,6 @@ as options will be ignored and overwritten, and the plugin
 named will also be benchmarked even if you attempted to
 exclude it with the C<skip_plugin> or C<only_plugin> options.
 
-You can supply multiple plugins to C<cache_types_from>, either
-by passing several C<cache_types_from> attributes, or by passing
-an arrayref of plugin names, or a hashref of plugin names with
-true/false values to toggle them on or off.
-The set of cache types chosen will then be the superset of cache
-types supported by those engines.
-
-  #  This sets the cache types to benchmark to all those supported by
-  #  Template::Benchmark::Engines::TemplateSandbox
-  $bench = Template::Benchmark->new(
-        cache_types_from => 'TemplateSandbox',
-        );
-
-  #  This sets the cache types to benchmark to all those supported by EITHER of
-  #  Template::Benchmark::Engines::MojoTemplate and
-  #  Template::Benchmark::Engines::HTMLTemplateCompiled
-  $bench = Template::Benchmark->new(
-        cache_types_from => 'MojoTemplate',
-        cache_types_from => 'HTMLTemplateCompiled',
-        );
-
-  #  This sets the features to benchmark to all those supported by EITHER of
-  #  Template::Benchmark::Engines::MojoTemplate and
-  #  Template::Benchmark::Engines::HTMLTemplateCompiled
-  $bench = Template::Benchmark->new(
-        cache_types_from => {
-            MojoTemplate         => 1,
-            HTMLTemplateCompiled => 1,
-            TemplateSandbox      => 0,
-            },
-        );
-
-Support for multiple C<cache_types_from> values was added in 1.09.
-
 =item B<template_repeats> => I<$number> (default 30)
 
 After the template is constructed from the various feature snippets
@@ -1131,26 +957,6 @@ take corresspondingly longer to run.
 The default of 10 seconds seems to give pretty consistent results for
 me within +/-1% on a very lightly loaded linux machine.
 
-=item B<dataset> => I<$dataset_name> (default 'original')
-
-=item B<dataset> => { B<hash1> => { I<variables> }, B<hash2> => { I<variables> } }
-
-Sets the dataset of I<template variables> to use for the benchmark
-function, either as the name of one of the presupplied datasets
-or as a hashref to a custom dataset.
-
-Currently the only presupplied dataset is 'original'.
-
-If supplying a custom dataset the hashref should consist of only
-two keys, named 'hash1' and 'hash2' the values of which will be
-passed as the two hashes of I<template variables> to each I<benchmark
-function>.
-
-Please see the section L</"CUSTOM DATASETS"> for more details on
-supplying your own datasets.
-
-The C<dataset> option was added in 1.04.
-
 =item B<style> => I<$string> (default 'none')
 
 This option is passed straight through as the C<style> argument
@@ -1179,25 +985,6 @@ Because the location is printed, and at an unpredictable time, it may
 mess up your program output, so this option is probably only useful
 while debugging.
 
-=item B<skip_output_compare> => I<0> | I<1> (default 0)
-
-If enabled, this option will skip the sanity check that compares the
-output of the different template engines to ensure that they're producing
-the same output.
-
-This is useful as a workaround if the sanity check is producing a
-mismatch error that you deem to be unimportant.
-
-It is strongly recommended that you never use this option without
-first manually checking the mismatched outputs to be certain that
-they are in fact unimportant.
-
-If you find yourself needing to use this option as a workaround,
-please file a bug report at
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Template-Benchmark>.
-
-The C<skip_output_compare> option was added in 1.05.
-
 =item B<only_plugin> => I<$plugin> (default none)
 
 =item B<skip_plugin> => I<$plugin> (default none)
@@ -1411,152 +1198,6 @@ namespace and inherit the L<Template::Benchmark::Engine> class.
 See the L<Template::Benchmark::Engine> documentation for details on writing
 your own plugins.
 
-=head1 CUSTOM DATASETS
-
-Starting with version 1.04, L<Template::Benchmark> has allowed you to
-supply your own data to use as I<template variables> within the benchmarks.
-
-This is done by supplying a hashref to the C<dataset> constructor option,
-with two keys, 'hash1' and 'hash2' which in-turn have hashref values which
-are to be used as the hashrefs of I<template variables> supplied to
-the I<benchmark functions>:
-
-    $bench = Template::Benchmark->new(
-        dataset => {
-            hash1 => {
-                scalar_variable => 'I is a scalar, yarr!',
-                hash_variable   => {
-                    'hash_value_key' =>
-                        'I spy with my little eye, something beginning with H.',
-                    },
-                array_variable   => [ qw/I have an imagination honest/ ],
-                this => { is => { a => { very => { deep => { hash => {
-                    structure => "My god, it be full of hashes.",
-                    } } } } } },
-                template_if_true  => 'True dat',
-                template_if_false => 'Nay, Mister Wilks',
-                },
-            hash2 => {
-                array_loop =>
-                    [ qw/five four three two one coming ready or not/ ],
-                hash_loop  => {
-                    aaa => 'first',
-                    bbb => 'second',
-                    ccc => 'third',
-                    ddd => 'fourth',
-                    eee => 'fifth',
-                    },
-                records_loop => [
-                    { name => 'Joe Bloggs',      age => 16,  },
-                    { name => 'Fred Bloggs',     age => 23,  },
-                    { name => 'Nigel Bloggs',    age => 43,  },
-                    { name => 'Tarquin Bloggs',  age => 143, },
-                    { name => 'Geoffrey Bloggs', age => 13,  },
-                    ],
-                variable_if      => 1,
-                variable_if_else => 0,
-                variable_expression_a => 20,
-                variable_expression_b => 10,
-                variable_function_arg => 'Hi there',
-                },
-            },
-        );
-
-There are no constraints on what I<template variable> belongs in
-C<hash1> and C<hash2>, just so long as it occurs once and only once
-in both.
-
-=over
-
-=item C<scalar_variable>
-
-This value gets interpolated into the template as part of the
-C<scalar_variable> feature, and can be any string value.
-
-=item C<hash_variable>
-
-Used by the C<hash_variable_value> feature, this value must be a
-hashref with key 'hash_value_key' pointing at a string value to
-be interpolated into the template.
-
-=item C<array_variable>
-
-Used by the C<array_variable_value> feature, this value must be an
-arrayref consisting of at least 3 elements, the third of which will
-be interpolated into the template.
-
-=item C<this>
-
-The base of a deep data-structure for use in the
-C<deep_data_structure_value> feature, this should be a nested
-series of hashrefs keyed in turn by 'this', 'is', 'a', 'very',
-'deep', 'hash', 'structure', with the final 'structure' key
-referring to a string value to interpolate into the template.
-
-=item C<array_loop>
-
-Used within the C<array_loop_value> and C<array_loop_template>
-features, this value should be an arrayref of any number of strings,
-all of which will be looped across and included in the template output.
-
-=item C<hash_loop>
-
-Used within the C<hash_loop_value> and C<hash_loop_template>
-features, this value should be a hashref of any number of string keys
-mapping to string values, all of which will be looped across and included
-in the template output.
-
-=item C<records_loop>
-
-Used within the C<records_loop_value> and C<records_loop_template>
-features, this value should be an arrayref of any number of hashrefs
-"records", each consisting of a 'name' key with a string value, and an
-'age' key with integer value.
-Each record will be iterated across and written to the template
-output.
-
-=item C<variable_if>
-
-=item C<variable_if_else>
-
-These two keys are used by the C<variable_if_*> and C<variable_if_else_*>
-features and should be set to a true or false integer which will determine
-which branch of the if-construct will be taken.
-
-=item C<template_if_true>
-
-=item C<template_if_false>
-
-These two keys should have distinct string values that will be
-interpolated into the template as the content in the
-C<*_if_template> and C<*_if_else_template> features,
-depending on which branch is taken.
-
-=item C<variable_expression_a>
-
-=item C<variable_expression_b>
-
-These two values are used in the C<variable_expression> and
-C<complex_variable_expression> features, and should be integer
-values.
-
-For most consistent results they should probably be chosen with
-care to keep the two features to integer mathematics to avoid
-rounding or floating-point inconsistencies between different
-template engines, the default values of 20 and 10 respectively
-do this.
-
-See the L<Template::Benchmark::Engine> documentation for further
-details.
-
-=item C<variable_function_arg>
-
-Used by the C<variable_function> feature, this value should be a string
-of at least 6 characters length, the 4th through 6th of which will be
-used in the template output.
-
-=back
-
 =head1 UNDERSTANDING THE RESULTS
 
 This section aims to give you a few pointers when analyzing the results
@@ -1727,10 +1368,6 @@ distribution entirely as it's not specifically to do with benchmarking.
 
 =back
 
-=head1 SEE ALSO
-
-L<Task::Template::Benchmark>
-
 =head1 AUTHOR
 
 Sam Graham, C<< <libtemplate-benchmark-perl BLAHBLAH illusori.co.uk> >>
