@@ -7,7 +7,7 @@ use base qw/Template::Benchmark::Engine/;
 
 use HTML::Template::Compiled;
 
-our $VERSION = '1.09_01';
+our $VERSION = '1.01';
 
 our %feature_syntaxes = (
     literal_text              =>
@@ -95,7 +95,7 @@ sub benchmark_functions_for_uncached_string
                     );
                 $t->param( $_[ 1 ] );
                 $t->param( $_[ 2 ] );
-                \$t->output();
+                $t->output();
             },
         } );
 }
@@ -122,7 +122,7 @@ sub benchmark_functions_for_uncached_disk
                     );
                 $t->param( $_[ 1 ] );
                 $t->param( $_[ 2 ] );
-                \$t->output();
+                $t->output();
             },
         } );
 }
@@ -150,7 +150,7 @@ sub benchmark_functions_for_disk_cache
                     );
                 $t->param( $_[ 1 ] );
                 $t->param( $_[ 2 ] );
-                \$t->output();
+                $t->output();
             },
         } );
 }
@@ -183,7 +183,7 @@ sub benchmark_functions_for_memory_cache
                     );
                 $t->param( $_[ 1 ] );
                 $t->param( $_[ 2 ] );
-                \$t->output();
+                $t->output();
             },
         } );
 }
