@@ -10,11 +10,9 @@ use Template::Sandbox::StringFunctions qw/substr/;
 
 use Cache::CacheFactory;
 use Cache::FastMmap;
-use Cache::FastMemoryCache;
-use Cache::Ref::FIFO;
 use CHI;
 
-our $VERSION = '1.09_01';
+our $VERSION = '1.01';
 
 our %feature_syntaxes = (
     literal_text              =>
@@ -89,12 +87,6 @@ sub benchmark_descriptions
         TS_CHI =>
             "Template::Sandbox ($Template::Sandbox::VERSION) with " .
             "CHI ($CHI::VERSION) caching",
-        TS_CFM =>
-            "Template::Sandbox ($Template::Sandbox::VERSION) with " .
-            "Cache::FastMemoryCache ($Cache::FastMemoryCache::VERSION) caching",
-        TS_CRF =>
-            "Template::Sandbox ($Template::Sandbox::VERSION) with " .
-            "Cache::Ref::FIFO ($Cache::Ref::FIFO::VERSION) caching",
         TS_FMM =>
             "Template::Sandbox ($Template::Sandbox::VERSION) with " .
             "Cache::FastMmap ($Cache::FastMmap::VERSION) caching",
@@ -113,7 +105,7 @@ sub benchmark_functions_for_uncached_string
                 $t->set_template_string( $_[ 0 ] );
                 $t->add_vars( $_[ 1 ] );
                 $t->add_vars( $_[ 2 ] );
-                $t->run();
+                ${$t->run()};
             },
         } );
 }
@@ -132,7 +124,7 @@ sub benchmark_functions_for_uncached_disk
                     );
                 $t->add_vars( $_[ 1 ] );
                 $t->add_vars( $_[ 2 ] );
-                $t->run();
+                ${$t->run()};
             },
         } );
 }
@@ -162,7 +154,7 @@ sub benchmark_functions_for_disk_cache
                     );
                 $t->add_vars( $_[ 1 ] );
                 $t->add_vars( $_[ 2 ] );
-                $t->run();
+                ${$t->run()};
             },
         TS_CHI =>
             sub
@@ -175,7 +167,7 @@ sub benchmark_functions_for_disk_cache
                     );
                 $t->add_vars( $_[ 1 ] );
                 $t->add_vars( $_[ 2 ] );
-                $t->run();
+                ${$t->run()};
             },
         } );
 }
@@ -207,7 +199,7 @@ sub benchmark_functions_for_shared_memory_cache
                     );
                 $t->add_vars( $_[ 1 ] );
                 $t->add_vars( $_[ 2 ] );
-                $t->run();
+                ${$t->run()};
             },
         TS_CHI =>
             sub
@@ -220,7 +212,7 @@ sub benchmark_functions_for_shared_memory_cache
                     );
                 $t->add_vars( $_[ 1 ] );
                 $t->add_vars( $_[ 2 ] );
-                $t->run();
+                ${$t->run()};
             },
         } );
 }
@@ -228,7 +220,7 @@ sub benchmark_functions_for_shared_memory_cache
 sub benchmark_functions_for_memory_cache
 {
     my ( $self, $template_dir, $cache_dir ) = @_;
-    my ( $cf, $chi, $cfm, $crf );
+    my ( $cf, $chi );
 
     $cf = Cache::CacheFactory->new(
         storage       => 'fastmemory',
@@ -238,10 +230,6 @@ sub benchmark_functions_for_memory_cache
         driver  => 'Memory',
         global  => 1,
         );
-    $cfm = Cache::FastMemoryCache->new();
-    $crf = Cache::Ref::FIFO->new(
-        size    => 1024,
-        );
 
     return( {
         TS_CF =>
@@ -255,7 +243,7 @@ sub benchmark_functions_for_memory_cache
                     );
                 $t->add_vars( $_[ 1 ] );
                 $t->add_vars( $_[ 2 ] );
-                $t->run();
+                ${$t->run()};
             },
         TS_CHI =>
             sub
@@ -268,33 +256,7 @@ sub benchmark_functions_for_memory_cache
                     );
                 $t->add_vars( $_[ 1 ] );
                 $t->add_vars( $_[ 2 ] );
-                $t->run();
-            },
-        TS_CFM =>
-            sub
-            {
-                my $t = Template::Sandbox->new(
-                    cache         => $cfm,
-                    template_root => $template_dir,
-                    template      => $_[ 0 ],
-                    ignore_module_dependencies => 1,
-                    );
-                $t->add_vars( $_[ 1 ] );
-                $t->add_vars( $_[ 2 ] );
-                $t->run();
-            },
-        TS_CRF =>
-            sub
-            {
-                my $t = Template::Sandbox->new(
-                    cache         => $crf,
-                    template_root => $template_dir,
-                    template      => $_[ 0 ],
-                    ignore_module_dependencies => 1,
-                    );
-                $t->add_vars( $_[ 1 ] );
-                $t->add_vars( $_[ 2 ] );
-                $t->run();
+                ${$t->run()};
             },
         } );
 }
@@ -324,7 +286,7 @@ sub benchmark_functions_for_instance_reuse
                 }
                 $t->add_vars( $_[ 1 ] );
                 $t->add_vars( $_[ 2 ] );
-                $t->run();
+                ${$t->run()};
             },
         } );
 }
