@@ -8,7 +8,7 @@ use base qw/Template::Benchmark::Engine/;
 use Text::MicroTemplate;
 use Text::MicroTemplate::File;
 
-our $VERSION = '1.09_01';
+our $VERSION = '1.01';
 
 our %feature_syntaxes = (
     literal_text              =>
@@ -102,7 +102,7 @@ sub benchmark_functions_for_uncached_string
                     template    => $_[ 0 ],
                     escape_func => undef,
                     );
-                \$t->render_mt( { %{$_[ 1 ]}, %{$_[ 2 ]} } );
+                $t->render_mt( { %{$_[ 1 ]}, %{$_[ 2 ]} } );
             },
         } );
 }
@@ -111,6 +111,13 @@ sub benchmark_functions_for_uncached_disk
 {
     my ( $self, $template_dir ) = @_;
 
+    return( undef );
+}
+
+sub benchmark_functions_for_disk_cache
+{
+    my ( $self, $template_dir, $cache_dir ) = @_;
+
     return( {
         TeMT =>
             sub
@@ -120,18 +127,11 @@ sub benchmark_functions_for_uncached_disk
                     escape_func  => undef,
                     use_cache    => 0,
                     );
-                \$t->render_file( $_[ 0 ], { %{$_[ 1 ]}, %{$_[ 2 ]} } );
+                $t->render_file( $_[ 0 ], { %{$_[ 1 ]}, %{$_[ 2 ]} } );
             },
         } );
 }
 
-sub benchmark_functions_for_disk_cache
-{
-    my ( $self, $template_dir, $cache_dir ) = @_;
-
-    return( undef );
-}
-
 sub benchmark_functions_for_shared_memory_cache
 {
     my ( $self, $template_dir, $cache_dir ) = @_;
@@ -150,9 +150,9 @@ sub benchmark_functions_for_memory_cache
                 my $t = Text::MicroTemplate::File->new(
                     include_path => [ $template_dir ],
                     escape_func  => undef,
-                    use_cache    => 2,
+                    use_cache    => 1,
                     );
-                \$t->render_file( $_[ 0 ], { %{$_[ 1 ]}, %{$_[ 2 ]} } );
+                $t->render_file( $_[ 0 ], { %{$_[ 1 ]}, %{$_[ 2 ]} } );
             },
         } );
 }
@@ -160,20 +160,8 @@ sub benchmark_functions_for_memory_cache
 sub benchmark_functions_for_instance_reuse
 {
     my ( $self, $template_dir, $cache_dir ) = @_;
-    my ( $t );
 
-    return( {
-        TeMT =>
-            sub
-            {
-                $t ||= Text::MicroTemplate::File->new(
-                    include_path => [ $template_dir ],
-                    escape_func  => undef,
-                    use_cache    => 2,
-                    );
-                \$t->render_file( $_[ 0 ], { %{$_[ 1 ]}, %{$_[ 2 ]} } );
-            },
-        } );
+    return( undef );
 }
 
 1;
